@@ -21,23 +21,15 @@
 
 'use strict';
 
-var webdriver = require('..'),
-    By = webdriver.By,
-    until = webdriver.until;
+const {Builder, By, Key, logging, until} = require('..');
 
-webdriver.logging.installConsoleHandler();
-webdriver.logging.getLogger('webdriver.http')
-    .setLevel(webdriver.logging.Level.ALL);
+logging.installConsoleHandler();
+logging.getLogger('webdriver.http').setLevel(logging.Level.ALL);
 
-var driver = new webdriver.Builder()
-    .forBrowser('firefox')
-    .build();
+var driver = new Builder().forBrowser('firefox').build();
 
-driver.get('http://www.google.com/ncr');
-
-var searchBox = driver.wait(until.elementLocated(By.name('q')), 3000);
-searchBox.sendKeys('webdriver');
-
-driver.findElement(By.name('btnG')).click();
-driver.wait(until.titleIs('webdriver - Google Search'), 1000);
-driver.quit();
+driver.get('http://www.google.com/ncr')
+    .then(_ =>
+        driver.findElement(By.name('q')).sendKeys('webdriver', Key.RETURN))
+    .then(_ => driver.wait(until.titleIs('webdriver - Google Search'), 1000))
+    .then(_ => driver.quit());
