@@ -293,14 +293,7 @@ describe('http', function() {
         });
 
         it('auto-upgrades on W3C response', function() {
-          let rawResponse = {
-            value: {
-              sessionId: 's123',
-              value: {
-                name: 'Bob'
-              }
-            }
-          };
+          var rawResponse = {sessionId: 's123', value: {name: 'Bob'}};
 
           send.returns(Promise.resolve(
               new http.Response(200, {}, JSON.stringify(rawResponse))));
@@ -332,38 +325,6 @@ describe('http', function() {
             assert.ok(executor.w3c, 'should never downgrade');
           });
         });
-
-        it('handles legacy new session failures', function() {
-          let rawResponse = {
-            status: error.ErrorCode.NO_SUCH_ELEMENT,
-            value: {message: 'hi'}
-          };
-
-          send.returns(Promise.resolve(
-              new http.Response(500, {}, JSON.stringify(rawResponse))));
-
-          return executor.execute(command)
-              .then(() => assert.fail('should have failed'),
-                    e => {
-                      assert.ok(e instanceof error.NoSuchElementError);
-                      assert.equal(e.message, 'hi');
-                    });
-        });
-
-        it('handles w3c new session failures', function() {
-          let rawResponse =
-              {value: {error: 'no such element', message: 'oops'}};
-
-          send.returns(Promise.resolve(
-              new http.Response(500, {}, JSON.stringify(rawResponse))));
-
-          return executor.execute(command)
-              .then(() => assert.fail('should have failed'),
-                    e => {
-                      assert.ok(e instanceof error.NoSuchElementError);
-                      assert.equal(e.message, 'oops');
-                    });
-        });
       });
 
       describe('extracts Session from DESCRIBE_SESSION response', function() {
@@ -437,7 +398,7 @@ describe('http', function() {
         });
 
         it('does not auto-upgrade on W3C response', function() {
-          var rawResponse = {value: {sessionId: 's123', value: {name: 'Bob'}}};
+          var rawResponse = {sessionId: 's123', value: {name: 'Bob'}};
 
           send.returns(Promise.resolve(
               new http.Response(200, {}, JSON.stringify(rawResponse))));
